@@ -12,58 +12,62 @@ PDL::Graphics::Prima::DataSet - the way we think about data
 
 =head1 SYNOPSIS
 
- -distribution => ds::Set(
-     $data, plotType => pset::CDF
+ -distribution => ds::Dist(
+     $data, plotType => ppair::Lines,
+     binning => bt::Linear,
  ),
  -lines => ds::Pair(
-     $x, $y, plotType => [ppair::Lines, ppair::Diamonds]
+     $x, $y, plotTypes => [ppair::Lines, ppair::Diamonds]
  ),
  -contour => ds::Grid(
-     $matrix, bounds => [$left, $bottom, $right, $top],
-              y_edges => $ys, x_bounds => [$left, $right],
-              x_edges => $xs, y_bounds => [$bottom, $top],
-              plotType => pgrid::Matrix(palette => $palette),
+     $matrix,
+     # Specify your bounds in one of these three ways
+     bounds => [$left, $bottom, $right, $top],
+     y_edges => $ys, x_edges => $xs, 
+     x_bounds => [$left, $right], y_bounds => [$bottom, $top],
+     # Unnecessary if you want the default palette
+     plotType => pgrid::Matrix(palette => $palette),
  ),
  -image => ds::Image(
      $image, format => 'string',
-             ... ds::Grid bounder options ...
-             plotType => pimage::Basic,
+     ... ds::Grid bounder options ...
+     # Unnecessary at the moment
+     plotType => pimage::Basic,
  ),
  -function => ds::Func(
      $func_ref, xmin => $left, xmax => $right, N_points => 200,
  ),
- -func_grid => ds::FGrid(
-     $matrix, ... same as for ds::Grid ...
-              N_points => 200,
-              N_points => [200, 300],
- ),
  
 
 =head1 DESCRIPTION
 
-C<PDL::Graphics::Prima> differentiates between a few kinds of data: Sets,
-Pair collections, and Grids. A Set is an unordered collection of data, such as the
-heights of a class of students. A Pair collection is an collection of x/y
-pairs, such as a time series. A Grid is, well, a matrix, such as the pixel
-colors of a photograph.
+C<PDL::Graphics::Prima> fundamentally conceives of two different kinds of
+data representations. There are pairwise representations, such as line plot
+used to visualize a time series, and there are gridded representations,
+such as raster images used to visualize heat maps (or images). Any data that
+you want to represent must have some way to conceive of itself as either
+pairwise or gridded.
 
-working here - this needs to be cleaned up!
+Of course, there are plenty of things we want to visualize that are not
+pairwise data or grids. For example, what if we want to plot the
+distribution of scores on an exam? In this case, we would probably use a
+histogram. When you think about it, a histogram is just a pairwise
+visual representation. In other words, to visualize a distribution, we have
+to first map the distribution into a pairwise representation, and then
+choose an appropriate way to visualize that representation, in this case a
+histogram.
 
-In addition, there are two derived kinds of datasets when you wish to specify
-a function instead of raw set of data. For example, to plot an analytic function,
-you could use a Function instead of Pairs. This has the advantage that if
-you zoom in on the function, the curve is recalculated and looks smooth instead
-of jagged. Similarly, if you can describe a surface by a function, you can plot
-that function using a function grid, i.e. FGrid.
-
-Once upon a time, this made sense, but it needs to be revised:
-
- At the moment there are two kinds of datasets. The piddle-based datasets have
- piddles for their x- and y-data. The function-based datasets create their
- x-values on the fly and evaluate their y-values using the supplied function
- reference. The x-values are generated using the C<sample_evenly> function which
- belongs to the x-axis's scaling object/class. As such, any scaling class needs
- to implement a C<sample_evenly> function to support function-based datasets.
+So, we have two fundamental ways to represent data, but many possible
+data sets. For pairwise representations, we have L<ds::Pair|/Pair>, the
+basic pairwise DataSet. L<ds::Dist|/Dist> is a derived DataSet which
+includes a binning specification that bins the distribution into bin centers
+(x) and heights (y) to get a pairwise representation. L<ds::Func|/Func>
+is another derived DataSet that generates evenly sampled data based on the
+axis bounds and evaluates the supplied function at those points to get a
+pairwise representation. L<ds::Image|/Image> provides a simple means for
+visualizing images, and L<ds::Grid|/Grid> provides a means for mapping a
+gridded collection of data into an image, using
+L<palettes|PDL::Graphics::Prima::Palette/>.
 
 =head2 Base Class
 
@@ -76,6 +80,7 @@ These include accessing the associated widget and drawing the data.
 
 package PDL::Graphics::Prima::DataSet;
 use Carp;
+use Scalar::Util;
 
 =item widget
 
@@ -87,9 +92,11 @@ sub widget {
 	# Simply return the widget if it's a getter:
 	return $_[0]->{widget} if @_ == 1;
 	
-	# It's a setter call, so set self's widget
+	# It's a setter call, so set self's widget. Note the use of weaken to avoid
+	# circular references and memory leaks.
 	my ($self, $widget) = @_;
 	$self->{widget} = $widget;
+	Scalar::Util::weaken($self->{widget});
 }
 
 =item draw
@@ -139,7 +146,11 @@ sub compute_collated_min_max_for {
 	my ($self, $axis_name, $pixel_extent) = @_;
 	my $widget = $self->{dataSets}->{widget};
 	
-	my (@min_collection, @max_collection);
+	# Add an initial collection of bad values to handle the special calse of
+	# no data sets.
+	my @min_collection = (PDL->zeroes($pixel_extent+1)->setvaltobad(0));
+	my @max_collection = (PDL->zeroes($pixel_extent+1)->setvaltobad(0));
+
 	foreach my $plotType (@{$self->{plotTypes}}) {
 		
 		# Accumulate all the collated results
@@ -303,130 +314,6 @@ sub change_data {
 
 =cut
 
-################################################################################
-#                                     Sets                                     #
-################################################################################
-
-package PDL::Graphics::Prima::DataSet::Set;
-use base 'PDL::Graphics::Prima::DataSet';
-use Carp;
-
-=head2 Sets
-
-Sets are unordered collections of sample data. The typical use case of set data
-is that you have a population of things and you want to analyze their agregate
-properties. For example, you might be interested in the distribution of tree
-heights at your Christmas Tree Farm, or the distribution of your students' (or
-your classmates') test scores from the mid-term. Those collections of data are
-called Sets and PDL::Graphics::Prima provides a number of ways of visualizing
-sets, as discussed under L<PDL::Graphics::Prima::PlotType/Sets>. Here, I
-discuss how to create and manipulate Set dataSet objects.
-
-Note that shape of pluralized properties (i.e. C<colors>) should
-thread-match the shape of the data B<excluding> the data's first dimension.
-That is, if I want to plot the cumulative distributions for three different
-batches using three different line colors, my data would have shape (N, 3) and
-my colors piddle would have shape (3).
-
-=over
-
-=item ds::Set - short-name constructor
-
-=for sig
-
-    ds::Set($data, option => value, ...)
-
-The short-name constructor to create sets. The data can be either a piddle of
-values or an array reference of values (which will be converted to a piddle
-during initialization).
-
-=cut
-
-sub ds::Set {
-	croak('ds::Set expects data and then key => value pairs, but you supplied'
-		. ' an even number of arguments') if @_ % 2 == 0;
-	my $data = shift;
-	return PDL::Graphics::Prima::DataSet::Set->new(@_, data => $data);
-}
-
-=item expected_plot_class
-
-Sets expect plot type objects that are derived from 
-C<PDL::Graphics::Prima::PlotType::Set>.
-
-=cut
-
-sub expected_plot_class {'PDL::Graphics::Prima::PlotType::Set'}
-
-# Standard initialization, and ensures that the data is a piddle.
-sub init {
-	my $self = shift;
-	
-	# Supply a default plot type:
-	$self->{plotTypes} = [pset::CDF()] unless exists $self->{plotTypes};
-	
-	# Check that the plotTypes are valid:
-	$self->check_plot_types(@{$self->{plotTypes}});
-	
-	# Set the data (without notifications)
-	$self->_change_data($self->{data});
-}
-
-=item get_data
-
-Returns the piddle containing the data. This is used mostly by the plotTypes to
-retrieve the data in order to display it. You can also use it to retrieve the
-data piddle if it makes your code more legible.
-
-=for example
-
- my $heights = load_height_data();
- ...
- my $plot = $wDisplay->insert('Plot',
-     -heights => ds::Set($heights),
-     ...
- );
- 
- # Retrieve and print the data:
- print "heights are ", $plot->dataSets->{heights}, "\n";
-
-A subtle point: notice that you can change the data B<within> the piddle, and
-you can even change the piddle's shape, but you cannot use this to replace the
-piddle itself.
-
-=cut
-
-sub get_data {
-	return $_[0]->{data};
-}
-
-=item change_data
-
-Changes the data to the piddle passed in. For example,
-
- if ($heights->changed) {
-     my $new_heights = $heights->data;
-     $heights_plot->dataSets->{'heights'}->change_data($new_heights);
- }
-
-=cut
-
-# Notification free method
-sub _change_data {
-	my ($self, $data) = @_;
-	
-	# Ensure the data is a piddle:
-	eval {
-		$self->{data} = PDL::Core::topdl($data);
-		1;
-	} or croak('For Set datasets, the data must be piddles '
-		. 'or scalars that pdl() knows how to process');
-}
-
-=back
-
-=cut
-
 ###############################################################################
 #                                    Pair                                    #
 ###############################################################################
@@ -552,8 +439,566 @@ sub _change_data {
 
 =cut
 
-# working here - create an OrderedSet, which only requires a single set of
-# data and uses counting numbers for the "x" values
+################################################################################
+#                                     Dist                                     #
+################################################################################
+
+package PDL::Graphics::Prima::DataSet::Dist;
+use base 'PDL::Graphics::Prima::DataSet::Pair';
+use Carp;
+
+
+#NOTE: I WOULD LIKE TO MAKE THE TRUNCATION BEHAVIOR MORE SPECIFIABLE WITH
+#FLAGS SUCH AS trunc::LeftDrop | trunc::RightExtraBin. I WOULD ALSO LIKE TO
+#INCLUDE norm::Integral, norm::ByWidth, norm::ByCount, OR MAYBE
+#norm::ToOne, norm::ToN, norm::ByWidth, norm::NotByWidth, SOMETHING LIKE THAT.
+
+=head2 Distribution
+
+Distributions are unordered collections of sample data. The typical use case
+of a distribution is that you have a population of things and you want to
+analyze their agregate properties. For example, you might be interested in
+the distribution of tree heights at your Christmas Tree Farm, or the
+distribution of your students' (or your classmates') test scores from the
+mid-term. Common ways for visualizing distributions are to plot their
+cumulative distribution functions or their histogram, but those are actually
+classic pairwise data visualization approaches. That means that what we really
+need are means for converting unordered sets of data into pairwise data.
+Distributions, therefore, let you specify the means by which your unordered
+data should be transformed into pairwise data, and the pairwise plot types to
+visualize the resulting transformed data. In an object oriented sense, the
+Distribution class is derived from the Pairwise class because a distribution
+B<is visualized> using pairwise plot types.
+
+Note that shape of pluralized properties (i.e. C<colors>) should
+thread-match the shape of the data B<excluding> the data's first dimension.
+That is, if I want to plot the cumulative distributions for three different
+batches using three different line colors, my data would have shape (N, 3) and
+my colors piddle would have shape (3).
+
+PDL::Graphics::Prima's notion of distributions is not yet finalized and is
+open to suggestion. If you find yourself using distribution plots regularly,
+you should give me feedback on what works and what doesn't. Thanks!
+
+=over
+
+=item ds::Dist - short-name constructor
+
+=for sig
+
+    ds::Dist($data, option => value, ...)
+
+The short-name constructor to create distribtions. The data can be either a
+piddle of values or an array reference of values (which will be converted to
+a piddle during initialization).
+
+=cut
+
+package 
+bt;
+
+use Carp;
+
+=pod
+
+In addition to the standard keys, there is also the C<binning> key. The
+C<binning> key expects either a standard binning approach using one of the
+pre-defined forms, or a subroutine reference that performs the binning
+in a customized fashion. The binning types are all functions that expect
+key/value pairs that include C<min> and C<max> for the lower and upper
+threshold of the binning, C<drop_extremes> to indicate if the data outside
+the min/max range should be included in the first and last bins, and
+C<normalize> to indicate if the binning should be normalized to 1, for some
+appropriate definition of normalization. Other keys may also be allowed.
+
+If you want to write a customized binning function, it should accept the
+two arguments, the C<data> to bin and the C<distribution> object. It should
+return a pair of piddles representing the x and y coordinates to plot. In
+addition, if the binning routine knows how to calculate properties for
+specific plot types, it can specify the plot type and any properties that it
+would provide for that plot type.
+
+For example, if you write a binning routine that knows how to calculate
+the bin boundaries for the Histogram plot type, your return statement could
+look like this:
+
+ return ($x, $y, Histogram => { binEdges => $bounds } );
+
+If your binning routine uses the number of points in a Symbols plot type to
+represent something, it could specify those:
+
+ return ($x, $y, Symbols => { N_points => $n_points } );
+
+If you have a means for calculating the error on your bins, you could
+include the error bar data:
+
+ return ($x, $y, ErrorBars => { y_err => $count_err } );
+
+These properties will be applied to the relevant plot types just before
+drawing and autoscaling operations, and any dataset operation that makes
+use of your supplied function should examine the additional parameters and
+act accordingly.
+
+The standard binning types include:
+
+=over
+
+=item bt::CDF
+
+Generates a cumulative distribution from the data. The default C<min> is the
+data's minimum, the default C<max> is the data's maximum, the binning will not
+C<drop_extremes> by default (i.e. C<< drop_extremes => 0 >>) and the binning
+normalizes the data (i.e. C<< normalize => 1 >>). You can also specify if you
+want an increasing or decreasing representation by specifying a boolean value
+for the C<increasing> key (the default is increasing, i.e. true).
+
+In the context of the CDF, normalization refers to the curve runnning from
+y = 0 to y = N - 1 (not normalized) or from y = 0 to y = 1 (normalized).
+Bear in mind that this interacts with your choice to drop the extremes or not.
+
+In producing the CDF, bad values are simply skipped.
+
+=cut
+
+sub get_min_max {
+	my ($data, $min, $max) = @_;
+	
+	# Calculate min and/or max from the data
+	if (not defined $min and not defined $max) {
+		($min, $max) = $data->minmaximum;
+	}
+	elsif (not defined $min) {
+		$min = $data->minimum;
+	}
+	elsif (not defined $max) {
+		$max = $data->maximum;
+	}
+	# Ensure supplied args are piddles
+	$min = PDL::Core::topdl($min);
+	$max = PDL::Core::topdl($max);
+	
+	# Return pdl-threadable results
+	return $min->dummy(0), $max->dummy(0);
+}
+
+sub CDF {
+	croak('bt::CDF expects key/value pairs but you supplied an odd number of arguments')
+		if @_ % 2 == 1;
+	my %opts = (drop_extremes => 0, normalize => 1, increasing => 1, @_);
+	
+	return sub {
+		my ($data, $set_obj) = @_;
+		
+		my ($min, $max) = get_min_max($data, $opts{min}, $opts{max});
+		
+		# The normalization term (also used in increasing/decreasing) depends
+		# on whether we drop the extreme values or not. The handling for the
+		# extreme values amounts to picking which of the x-values are bad and
+		# where they fall in their list so that they line up nicely with the
+		# result of the xvals function used to define the ys.
+		my ($norm, $xs);
+		if ($opts{drop_extremes}) {
+			$xs = $data->setbadif(($data < $min) | ($data > $max))->qsort;
+			$norm = ($xs->ngoodover - 1)->dummy(0);
+		}
+		else {
+			$norm = ($data->ngoodover - 1)->dummy(0);
+			$xs = $data->qsort->setbadif(($xs < $min) | ($xs > $max));
+		}
+		my $ys = $data->xvals;
+		
+		# alter the ys if they are supposed to decrease
+		$ys = $norm - $ys if not $opts{increasing};
+		
+		# Normalize, carefully
+		if ($opts{normalize}) {
+			$norm->where($norm == 0) .= 1;
+			$ys /= $norm;
+		}
+		
+		return ($xs, $ys);
+	};
+}
+
+=item bt::Linear
+
+Generates a histogram from the data with linear spacing. The default C<min> is the
+data's minimum, the default C<max> is the data's maximum, the binning will
+C<drop_extremes> by default (i.e. C<< drop_extremes => 1 >>) and the binning
+normalizes the data (i.e. C<< normalize => 1 >>). You can also specify the
+number of bins with C<nbins>. The default is 20. If you want empty bins to
+be marked as bad, specify C<< mark_empty_as => 'bad' >>. The default is to
+mark them as zero.
+
+In this case, normalization means that the "integral" of the histogram is
+1, which means that the sum of the heights I<times the widths> is 1.
+
+=cut
+
+# Takes the data, bounds, min, 
+sub bin_by_data {
+	my ($data, $bounds, $min, $max, $drop_extremes) = @_;
+	
+	my $is_within_bounds = ($min <= $data) & ($data <= $max);
+	my $idx = vsearch($data, $bounds);
+	
+	# Safety guard so indadd doesn't choke
+	$idx->where(!$is_within_bounds) .= 1;
+	# The actual minimum value will have idx 0, all others will be offest
+	# by 1, so adjust:
+	$idx->where($idx > 0)--;
+	
+	# Allocate the memory for the output piddle
+	my @dims = $bounds->dims;
+	$dims[0]--;
+	my $counts = zeroes(@dims);
+	
+	# Tabulate the contributions
+	indadd($is_within_bounds, $idx, $counts);
+	
+	# if we are not dropping the extremes, then we are dumping them into the
+	# first and last bins:
+	if (not $drop_extremes) {
+		$counts->slice('0')  += sum($data < $min);
+		$counts->slice('-1') += sum($data > $max);
+	}
+	
+	return $counts;
+}
+
+use PDL::NiceSlice;
+use PDL;
+sub Linear {
+	croak('bt::Linear expects key/value pairs but you supplied an odd number of arguments')
+		if @_ % 2 == 1;
+	my %opts = (drop_extremes => 1, normalize => 1, nbins => 20, 
+				mark_empty_as => 0, @_);
+	
+	return sub {
+		my ($data, $set_obj) = @_;
+		local *__ANNON__ = 'bt::Linear';
+		
+		# Get the appropriate min/max
+		my ($min, $max) = get_min_max($data, $opts{min}, $opts{max});
+		
+		# Edge conditions: min is the same as max
+		my $pos_min_eq_max = ($min == $max) & ($min > 0);
+		$min->where($pos_min_eq_max) /= 2;
+		$max->where($pos_min_eq_max) *= 1.5;
+		my $neg_min_eq_max = ($min == $max) & ($min < 0);
+		$min->where($neg_min_eq_max) *= 1.5;
+		$max->where($neg_min_eq_max) /= 2;
+		my $min_max_eq_zero = ($min == 0) & ($max == 0);
+		$min->where($min_max_eq_zero) .= -1;
+		$max->where($min_max_eq_zero) .= 1;
+		
+		# Build the bounds
+		my @dims = $data->dims;
+		$dims[0] = $opts{nbins} + 1;
+		my $bounds = zeroes(@dims)->xlinvals($min, $max);
+		
+		# Accumulate the counts
+		my $hist = bin_by_data($data => $bounds, $min, $max, $opts{drop_extremes});
+		
+		# Mark empties as bad, if requested
+		$hist = $hist->setvaltobad(0) if $opts{mark_empty_as} eq 'bad';
+		
+		if ($opts{normalize}) {
+			# Normalize by count
+			$hist /= $hist->sumover;
+			# normalize by bin width (same for all bins)
+			$hist /= ($bounds(1) - $bounds(0));
+		}
+		
+		# Return the bin centers and the heights, along with the histogram
+		# bin boundaries.
+		return (($bounds(1:-1) + $bounds(0:-2))/2, $hist,
+				Histogram => { binEdges => $bounds }
+		);
+	};
+}
+no PDL::NiceSlice;
+
+=item bt::Log
+
+Generates a histogram from the data with logarithmic spacing. The default
+C<min> is the data's smallest positive value and the default max is the data's
+maximum value. If none of the data is positive, the binning type croaks.
+The binning will C<drop_extremes> by default (i.e. C<< drop_extremes => 1 >>)
+and the binning normalizes the data (i.e. C<< normalize => 1 >>). You can also
+specify the number of bins with C<nbins>. The default is 20. If you want empty bins to
+be marked as bad, specify C<< mark_empty_as => 'bad' >>. The default is to
+mark them as zero.
+
+As with linear binning, normalization means that the "integral" of the histogram is
+1, which means that the sum of the heights I<times the widths> is 1.
+
+=item bt::StrictLog
+
+Identical to L<bt::Log|/bt::Log>, except that it croaks if it encounters
+B<any> negative values. You can use this in place of L<bt::Log|/bt::Log> to
+sanity check your data.
+
+=back
+
+=cut
+
+sub Log {
+	croak('bt::Log expects key/value pairs but you supplied an odd number of arguments')
+		if @_ % 2 == 1;
+	my %opts = (drop_extremes => 1, normalize => 1, nbins => 20,
+				mark_empty_as => 0, @_);
+	
+	return sub {
+		my ($data, $set_obj) = @_;
+		local *__ANNON__ = 'bt::Log';
+		
+		# Loose check condition: only croak if *everything* is negative
+		my ($min, $max) = get_min_max($data->setbadif($data <= 0), $opts{min}, $opts{max});
+		croak('data, or its truncation, seems to only contain negative values')
+			if any $max->isbad;
+		
+		return logarithmic_binning($data, $set_obj, $min, $max, \%opts);
+	};
+}
+
+sub StrictLog {
+	croak('bt::StrictLog expects key/value pairs but you supplied an odd number of arguments')
+		if @_ % 2 == 1;
+	my %opts = (drop_extremes => 1, normalize => 1, nbins => 20,
+				mark_empty_as => 0, @_);
+	
+	return sub {
+		my ($data, $set_obj) = @_;
+		local *__ANNON__ = 'bt::StrictLog';
+		
+		# Strict check condition: croak if *any* data is negative
+		my ($min, $max) = get_min_max($data, $opts{min}, $opts{max});
+		croak('data, or its truncation, seems to only contain negative values')
+			if any ($min < 0) or any $min->isbad;
+		
+		return logarithmic_binning($data, $set_obj, $min, $max, \%opts);
+	};
+}
+
+use PDL::NiceSlice;
+sub logarithmic_binning {
+	# By the time this gets called, all cleaning of the min and max should
+	# have happened, and they should both contain only strictly positive
+	# values.
+	my ($data, $set_obj, $min, $max, $opts) = @_;
+	
+	# Edge conditions: min is the same as max (Note that they will be
+	# strictly larger than zero since all negative values were removed
+	# before being sent to get_min_max). In that case, the special case
+	# of 1 must be handled with care, but otherwise it's pretty easy.
+	# Note that the values are chosen so that the bin centers, calculated
+	# below, work out correctly.
+	my $min_eq_max_eq_1 = ($min == $max) & ($max == 1);
+	$min->where($min_eq_max_eq_1) .= 0.5;
+	$max->where($min_eq_max_eq_1) .= 2;
+	my $min_eq_max_lt_1 = ($min == $max) & ($max < 1);
+	$min->where($min_eq_max_lt_1) **= 1.5;
+	$max->where($min_eq_max_lt_1) **= 0.5;
+	my $min_eq_max_gt_1 = ($min == $max) & ($max > 1);
+	$min->where($min_eq_max_gt_1) **= 0.5;
+	$max->where($min_eq_max_gt_1) **= 1.5;
+	
+	# Build the bounds
+	my @dims = $data->dims;
+	$dims[0] = $opts->{nbins} + 1;
+	my $bounds = zeroes(@dims)->xlogvals($min, $max);
+	
+	# Accumulate the counts
+	my $hist = bin_by_data($data => $bounds, $min, $max, $opts->{drop_extremes});
+	
+	# Mark empties as bad, if requested
+	$hist = $hist->setvaltobad(0) if $opts->{mark_empty_as} eq 'bad';
+
+	if ($opts->{normalize}) {
+		# Normalize by count
+		$hist /= $hist->sumover;
+		# normalize by bin width
+		$hist /= ($bounds(1:) - $bounds(:-2));
+	}
+	
+	# Return the bin centers and the heights, along with the histogram
+	# bin boundaries.
+	return (sqrt($bounds(1:-1) * $bounds(0:-2)), $hist,
+			Histogram => { binEdges => $bounds }
+	);
+}
+no PDL::NiceSlice;
+
+=item bt::NormFit
+
+"Fits" the distribution between the specified min and max (defaults to the
+data's min and max) to a normal distribution. This bin type does not pay
+attention to the C<drop_extremes> key, but it cares about the C<normalize>
+key. If unspecified (the default), the curve will be scaled so that the area
+underneath it is the number of data points being fit. If normalized, the
+curve will be scaled so that the area under the curve will be 1. You can
+also specify the number of points to use in generating the curves by including
+the C<N_points> key/value pair.
+
+I am pondering allowing the curve's min/max to take the current axis bounds
+min/max if the axes are not autoscaling. Thoughts appreciated.
+
+=cut
+
+sub NormFit {
+	croak('bt::NormFit expects key/value pairs but you supplied an odd number of arguments')
+		if @_ % 2 == 1;
+	my %opts = (normalize => 1, nbins => 20, N_points => 200, @_);
+	
+	return sub {
+		my ($data, $set_obj) = @_;
+		local *__ANNON__ = 'bt::NormFit';
+		
+		my ($min, $max) = get_min_max($data, $opts{min}, $opts{max});
+		my $data_to_analyze = $data->setbadif(($data < $min) | ($data > $max));
+		my ($means, $stdevs) = $data_to_analyze->dummy(1, 1)->statsover;
+		
+		my @dims = $data->dims;
+		$dims[0] = $opts{N_points};
+		my $xs = zeroes(@dims)->xlinvals($min, $max);
+		use PDL::Constants qw(PI);
+		my $ys = exp(-($xs - $means)**2 / 2 / $stdevs**2)
+				/ sqrt(2 * PI) / $stdevs;
+		$ys *= $data_to_analyze->ngoodover->dummy(0)
+			if not $opts{normalize};
+		
+		return ($xs, $ys);
+	};
+}
+
+package PDL::Graphics::Prima::DataSet::Dist;
+our @ISA = qw(PDL::Graphics::Prima::DataSet::Pair);
+
+sub ds::Dist {
+	croak('ds::Dist expects data and then key => value pairs, but you supplied'
+		. ' an even number of arguments') if @_ % 2 == 0;
+	my $data = shift;
+	return PDL::Graphics::Prima::DataSet::Dist->new(@_, data => $data);
+}
+
+# Standard initialization, and ensures that the data is a piddle.
+sub init {
+	my $self = shift;
+	
+	# Supply a default plot type:
+	$self->{plotTypes} = [ppair::Histogram()] unless exists $self->{plotTypes};
+	
+	# Check that the plotTypes are valid:
+	$self->check_plot_types(@{$self->{plotTypes}});
+	
+	# Make sure we have a binning type
+	$self->{binning} = bt::Linear() unless exists $self->{binning};
+	
+	# Set the data (without notifications)
+	$self->_change_data($self->{data});
+}
+
+=item get_data, get_xs, get_ys
+
+Returns the binned data, just the x-values, or just the y-values. For all of
+these, the binning function is applied to the current dataset. However, for
+the x- or y-getters, the other piece of data is discarded.
+
+=cut
+
+sub get_data {
+	my $self = shift;
+	# Send the cached values if they exist
+	return ($self->{x}, $self->{y}) if exists $self->{x};
+	# Otherwise pull them from the binning function
+	my ($xs, $ys) = $self->{binning}->($self->{data}, $self);
+	return ($xs, $ys);
+}
+
+sub get_xs {
+	my $self = shift;
+	return $self->{x} if exists $self->{x};
+	my ($xs) = $self->get_data;
+	return $xs;
+}
+
+sub get_ys {
+	my $self = shift;
+	return $self->{y} if exists $self->{y};
+	my (undef, $ys) = $self->get_data;
+	return $ys;
+}
+
+use Scalar::Util qw(blessed);
+
+# prep_plotTypes
+# A function to be called on $self with a collection of
+#  plotType => {
+#    key => value,
+#    key => value,
+#    ....
+#  }
+# to be set.
+sub prep_plotTypes {
+	my ($self, %args) = @_;
+	
+	# Run through all the plot types and apply any setters from the binning
+	for my $pt (@{$self->{plotTypes}}) {
+		my $type = blessed($pt);
+		if (exists $args{$type}) {
+			# We have some tweaks for this plot type. For now, just hack it
+			# by reaching into the plot type's internal storage. This needs
+			# to be done better. :-(  working here
+			#$pt->set(%{$args{$type}});
+			while (my ($k, $v) = each %{$args{$type}}) {
+				$pt->{$k} = $v;
+			}
+		}
+	}
+}
+
+sub draw {
+	my ($self, $canvas, $ratio) = @_;
+	
+	# Calculate and cache the x/y values; apply the plot type modifications
+	my ($x, $y, %mods) = $self->{binning}->($self->{data}, $self);
+	$self->{x} = $x;
+	$self->{y} = $y;
+	$self->prep_plotTypes(%mods);
+	
+	# Draw it!
+	$self->SUPER::draw($canvas, $ratio);
+	
+	# Remove the cacehd x/y values
+	delete $self->{x};
+	delete $self->{y};
+}
+
+sub compute_collated_min_max_for {
+	my ($self, $axis_name, $pixel_extent) = @_;
+	
+	# Calculate and cache the x/y values; apply the plot type modifications
+	my ($x, $y, %mods) = $self->{binning}->($self->{data}, $self);
+	$self->{x} = $x;
+	$self->{y} = $y;
+	$self->prep_plotTypes(%mods);
+	
+	# Call the parent method
+	my ($collated_min, $collated_max)
+		= $self->SUPER::compute_collated_min_max_for($axis_name, $pixel_extent);
+	
+	# Remove the cacehd x/y values
+	delete $self->{x};
+	delete $self->{y};
+	
+	# Return the collation results
+	return ($collated_min, $collated_max);
+}
+
+=back
+
+=cut
 
 ################################################################################
 #                                     Grid                                     #
@@ -564,7 +1009,7 @@ use base 'PDL::Graphics::Prima::DataSet';
 use Carp 'croak';
 use PDL;
 
-=head2 Grids
+=head2 Grid
 
 Grids are collections of data that is regularly ordered in two dimensions. Put
 differently, it is a structure in which the data is described by two indices.
@@ -1245,9 +1690,7 @@ sub compute_collated_min_max_for {
 =head2 Annotation
 
 PDL::Graphics::Prima provides a generic annotation dataset that is used for
-adding various annotations to your plots. It expects a list of key/value pairs
-where the keys are the names you give to your annotations and the values are
-annotation plotType objects.
+adding drawn or textual annotations to your plots.
 
 =cut
 
@@ -1259,6 +1702,7 @@ package PDL::Graphics::Prima::DataSet::Annotation;
 our @ISA = qw(PDL::Graphics::Prima::DataSet);
 
 use Carp 'croak';
+use Scalar::Util qw(blessed);
 
 =over
 
@@ -1266,9 +1710,11 @@ use Carp 'croak';
 
 =for sig
 
-    ds::Note(plotType, plotType, ...)
+    ds::Note(plotType, plotType, ..., drawing => option, drawing => option)
 
-The short-name constructor to create annotations. For example, 
+The short-name constructor to create annotations. This expects a list of
+annotation plot types fullowed by a list of general drawing options, such as
+line width or color. For example, 
 
 =for example
 
@@ -1276,19 +1722,49 @@ The short-name constructor to create annotations. For example,
      pnote::Region(
          # args here
      ),
+     pnote::Text('text',
+         # args here
+     ),
+     ... more note objects ...
+     # Dataset drawing options
+     color => cl::LightRed,
      ...
  );
 
+Unlike other dataset short-form constructors, you do not need to specify the
+plotTypes key explicitly, though if you did it would do what you mean. That is,
+the previous example would give identical results as this:
+
+ ds::Note(
+     plotTypes => [
+         pnote::Region(
+             # args here
+         ),
+         pnote::Text('text',
+             # args here
+         ),
+         ... more note objects ...
+     ],
+     # Dataset drawing options
+     color => cl::LightRed,
+     ...
+ );
+
+The former is simply offered as a convenience for this more long-winded form.
+
 =cut
 
 sub ds::Note {
-	return PDL::Graphics::Prima::DataSet::Annotation->new(plotTypes => [@_]);
+	# Pull all the note objects off the list
+	my @notes;
+	push (@notes, shift(@_))
+		while (blessed($_[0]) and $_[0]->isa('PDL::Graphics::Prima::PlotType::Annotation'));
+	croak("Non-note arguments must be key/value pairs") unless @_ % 2 == 0;
+	return PDL::Graphics::Prima::DataSet::Annotation->new(plotTypes => \@notes, @_);
 }
 
 sub expected_plot_class {'PDL::Graphics::Prima::PlotType::Annotation'}
 
-
-
 sub init {
 	my $self = shift;
 	
@@ -1342,6 +1818,7 @@ sub TIEHASH {
 sub DELETE {
 	my ($this, $key) = @_;
 	return if $key eq 'widget';
+	$key =~ s/^-//;  # strip any leading dash
 	delete $this->{$key};
 	$this->{widget}->notify('ChangeData');
 }
@@ -1353,6 +1830,12 @@ sub CLEAR {
 	$this->{widget}->notify('ChangeData');
 }
 
+sub FETCH {
+	my ($this, $key) = @_;
+	$key =~ s/^-//;  # strip any leading dash
+	return $this->{$key};
+}
+
 sub STORE {
 	my ($self, $name, $dataset) = @_;
 	# Silently do nothing if they try to change the widget:
@@ -1362,7 +1845,8 @@ sub STORE {
 	croak('You can only add dataSet objects to the collection of dataSets')
 		unless eval {$dataset->isa('PDL::Graphics::Prima::DataSet')};
 	
-	# Store it:
+	# strip any leading dash and store it
+	$name =~ s/^-//;
 	$self->{$name} = $dataset;
 	
 	# Inform the dataset of its parent widget:
@@ -1483,52 +1967,46 @@ tone.
 
 David Mertens (dcmertens.perl@gmail.com)
 
-=head1 SEE ALSO
+=head1 ADDITIONAL MODULES
 
-This is a component of L<PDL::Graphics::Prima>. This library is composed of many
-modules, including:
+Here is the full list of modules in this distribution:
 
 =over
 
-=item L<PDL::Graphics::Prima>
+=item L<PDL::Graphics::Prima|PDL::Graphics::Prima/>
 
 Defines the Plot widget for use in Prima applications
 
-=item L<PDL::Graphics::Prima::Axis>
+=item L<PDL::Graphics::Prima::Axis|PDL::Graphics::Prima::Axis/>
 
 Specifies the behavior of axes (but not the scaling)
 
-=item L<PDL::Graphics::Prima::DataSet>
+=item L<PDL::Graphics::Prima::DataSet|PDL::Graphics::Prima::DataSet/>
 
 Specifies the behavior of DataSets
 
-=item L<PDL::Graphics::Prima::Internals>
-
-A dumping ground for my partial documentation of some of the more complicated
-stuff. It's not organized, so you probably shouldn't read it.
-
-=item L<PDL::Graphics::Prima::Limits>
+=item L<PDL::Graphics::Prima::Limits|PDL::Graphics::Prima::Limits/>
 
 Defines the lm:: namespace
 
-=item L<PDL::Graphics::Prima::ReadLine>
+=item L<PDL::Graphics::Prima::Palette|PDL::Graphics::Prima::Palette/>
+
+Specifies a collection of different color palettes
+
+=item L<PDL::Graphics::Prima::PlotType|PDL::Graphics::Prima::PlotType/>
+
+Defines the different ways to visualize your data
+
+=item L<PDL::Graphics::Prima::ReadLine|PDL::Graphics::Prima::ReadLine/>
 
 Encapsulates all interaction with the L<Term::ReadLine> family of
 modules.
 
-=item L<PDL::Graphics::Prima::Palette>
-
-Specifies a collection of different color palettes
-
-=item L<PDL::Graphics::Prima::PlotType>
-
-Defines the different ways to visualize your data
-
-=item L<PDL::Graphics::Prima::Scaling>
+=item L<PDL::Graphics::Prima::Scaling|PDL::Graphics::Prima::Scaling/>
 
 Specifies different kinds of scaling, including linear and logarithmic
 
-=item L<PDL::Graphics::Prima::Simple>
+=item L<PDL::Graphics::Prima::Simple|PDL::Graphics::Prima::Simple/>
 
 Defines a number of useful functions for generating simple and not-so-simple
 plots
@@ -1540,10 +2018,10 @@ plots
 Portions of this module's code are copyright (c) 2011 The Board of Trustees at
 the University of Illinois.
 
-Portions of this module's code are copyright (c) 2011-2012 Northwestern
+Portions of this module's code are copyright (c) 2011-2013 Northwestern
 University.
 
-This module's documentation are copyright (c) 2011-2012 David Mertens.
+This module's documentation are copyright (c) 2011-2013 David Mertens.
 
 All rights reserved.
 
